[jboss-cvs] JBossAS SVN: r68133 - projects/microcontainer/trunk/kernel/src/main/org/jboss/kernel/plugins/dependency.

jboss-cvs-commits at lists.jboss.org jboss-cvs-commits at lists.jboss.org
Tue Dec 11 04:30:02 EST 2007


Author: alesj
Date: 2007-12-11 04:30:02 -0500 (Tue, 11 Dec 2007)
New Revision: 68133

Modified:
   projects/microcontainer/trunk/kernel/src/main/org/jboss/kernel/plugins/dependency/ConfigureAction.java
Log:
Typo.

Modified: projects/microcontainer/trunk/kernel/src/main/org/jboss/kernel/plugins/dependency/ConfigureAction.java
===================================================================
--- projects/microcontainer/trunk/kernel/src/main/org/jboss/kernel/plugins/dependency/ConfigureAction.java	2007-12-11 08:31:12 UTC (rev 68132)
+++ projects/microcontainer/trunk/kernel/src/main/org/jboss/kernel/plugins/dependency/ConfigureAction.java	2007-12-11 09:30:02 UTC (rev 68133)
@@ -73,21 +73,21 @@
     * @param target the target
     * @param info the bean info
     * @param metaData the bean metadata
     * @param nullyfy should we nullyfy attributes/properties
     * @throws Throwable for any error
     */
-   protected void setAttributes(Object target, BeanInfo info, BeanMetaData metaData, boolean nullyfy) throws Throwable
+   protected void setAttributes(Object target, BeanInfo info, BeanMetaData metaData, boolean nullify) throws Throwable
    {
       Set<PropertyMetaData> propertys = metaData.getProperties();
       if (propertys != null && propertys.isEmpty() == false)
       {
          ClassLoader cl = null;
-         if (nullyfy == false)
+         if (nullify == false)
             cl = Configurator.getClassLoader(metaData);
 
          for(PropertyMetaData property : propertys)
          {
-            dispatchSetProperty(property, nullyfy, info, target, cl);
+            dispatchSetProperty(property, nullify, info, target, cl);
          }
       }
    }
@@ -96,18 +96,18 @@
     * Dispatch property set
     *
     * @param property the property
     * @param nullyfy should we nullyfy
     * @param info the bean info
     * @param target the target
     * @param cl classloader
     * @throws Throwable for any error
     */
    // TODO - wrap with MetaDataStack push and ContextCL change?
-   protected void dispatchSetProperty(PropertyMetaData property, boolean nullyfy, BeanInfo info, Object target, ClassLoader cl)
+   protected void dispatchSetProperty(PropertyMetaData property, boolean nullify, BeanInfo info, Object target, ClassLoader cl)
          throws Throwable
    {
       String name = property.getName();
-      if (nullyfy)
+      if (nullify)
       {
          try
          {
@@ -73,21 +73,21 @@
     * @param info the bean info
     * @param metaData the bean metadata
-    * @param nullyfy should we nullyfy attributes/properties
+    * @param nullify should we nullify attributes/properties
     * @throws Throwable for any error
     */
@@ -96,18 +96,18 @@
     *
     * @param property the property
-    * @param nullyfy should we nullyfy
+    * @param nullify should we nullify
     * @param info the bean info
     * @param target the target




More information about the jboss-cvs-commits mailing list